@@ -163,7 +163,7 @@ Options:
          distribution name
   --bpo
          Increment the Debian release number for a backports upload
-         to "bullseye-backports"
+         to "bookworm-backports"
   --stable
          Increment the Debian release number for a stable upload.
   -l, --local <suffix>
@@ -465,7 +465,9 @@ fatal
   + ($opt_stable ? 1 : 0)
   + ($opt_l ? 1 : 0) > 1;
 
-if ($opt_s) {
+# FIXME shouldn't this be later so that the user can override the urgency,
+# e.g. "-s -ulow" ?
+if ($opt_s || $opt_lts) {
     $opt_u = "high";
 }
 
@@ -507,7 +509,7 @@ if ($vendor eq 'Ubuntu'
 if (defined $opt_D) {
     if ($vendor eq 'Debian') {
         unless ($opt_D
-            =~ /^(experimental|unstable|sid|UNRELEASED|((old){0,2}stable|testing|wheezy|jessie|stretch|buster|bullseye)(-proposed-updates|-security)?|proposed-updates)$/
+            =~ /^(experimental|unstable|sid|UNRELEASED|((old){0,2}stable|testing|buster|bullseye|bookworm|trixie)(-proposed-updates|-security)?|proposed-updates)$/
         ) {
             my $deb_info = get_debian_distro_info();
             my ($oldstable_backports, $stable_backports) = ("", "");
@@ -530,9 +532,9 @@ if (defined $opt_D) {
                   if $oldstable_backports;
                 warn "$progname warning: Recognised distributions are: \n"
                   . "experimental, unstable, testing, stable, oldstable, oldoldstable,\n"
-                  . "{bullseye,buster,stretch,jessie,wheezy}-proposed-updates,\n"
+                  . "{trixie,bookworm,bullseye,buster}-proposed-updates,\n"
                   . "{testing,stable,oldstable,oldoldstable}-proposed-updates,\n"
-                  . "{bullseye,buster,stretch,jessie,wheezy}-security,\n"
+                  . "{trixie,bookworm,bullseye,buster}-security,\n"
                   . "{testing,stable,oldstable,oldoldstable}}-security$oldstable_backports$stable_backports and UNRELEASED.\n"
                   . "Using your request anyway.\n";
                 $warnings++ if not $opt_force_dist;
@@ -668,12 +670,9 @@ my $MAINTAINER   = 'MAINTAINER';
 my $EMAIL        = 'EMAIL';
 my $DISTRIBUTION = 'UNRELEASED';
 # when updating the lines below also update the help text, the manpage and the testcases.
-my %dists = (
-    8,  'jessie',   9,  'stretch',  10, 'buster',
-    11, 'bullseye', 12, 'bookworm', 13, 'trixie'
-);
-my $lts_dist    = '9';
-my $latest_dist = '11';
+my %dists       = (10, 'buster', 11, 'bullseye', 12, 'bookworm', 13, 'trixie');
+my $lts_dist    = '10';
+my $latest_dist = '12';
 # dist guessed from backports, SRU, security uploads...
 my $guessed_dist = '';
 my $CHANGES      = '';
